@@ -39,6 +39,7 @@ type Analysis struct {
 	managed         []*resource.Resource
 	deleted         []*resource.Resource
 	differences     []Difference
+	options         AnalyzerOptions
 	summary         Summary
 	alerts          alerter.Alerts
 	Duration        time.Duration
@@ -69,6 +70,11 @@ type GenDriftIgnoreOptions struct {
 	ExcludeDeleted   bool
 	ExcludeDrifted   bool
 	InputPath        string
+	OutputPath       string
+}
+
+func NewAnalysis(options AnalyzerOptions) *Analysis {
+	return &Analysis{options: options}
 }
 
 func (a Analysis) MarshalJSON() ([]byte, error) {
@@ -155,6 +161,10 @@ func (a *Analysis) IsSync() bool {
 	return a.summary.TotalDrifted == 0 && a.summary.TotalUnmanaged == 0 && a.summary.TotalDeleted == 0
 }
 
+func (a *Analysis) Options() AnalyzerOptions {
+	return a.options
+}
+
 func (a *Analysis) AddDeleted(resources ...*resource.Resource) {
 	a.deleted = append(a.deleted, resources...)
 	a.summary.TotalResources += len(resources)
