@@ -9,6 +9,7 @@ import (
 	"syscall"
 	"time"
 
+	"github.com/cloudskiff/driftctl/build"
 	"github.com/cloudskiff/driftctl/pkg/analyser"
 	"github.com/cloudskiff/driftctl/pkg/memstore"
 	"github.com/cloudskiff/driftctl/pkg/remote/common"
@@ -168,6 +169,12 @@ func NewScanCmd(opts *pkg.ScanOptions) *cobra.Command {
 		"Terraform Cloud / Enterprise API token.\n"+
 			"Only used with tfstate+tfcloud backend.\n",
 	)
+	fl.StringVar(&opts.BackendOptions.TFCloudEndpoint,
+		"tfc-endpoint",
+		"https://app.terraform.io/api/v2",
+		"Terraform Cloud / Enterprise API endpoint.\n"+
+			"Only used with tfstate+tfcloud backend.\n",
+	)
 	fl.String(
 		"tf-provider-version",
 		"",
@@ -211,11 +218,17 @@ func NewScanCmd(opts *pkg.ScanOptions) *cobra.Command {
 func scanRun(opts *pkg.ScanOptions) error {
 	store := memstore.New()
 
-	c := make(chan os.Signal)
+	c := make(chan os.Signal, 1)
 	signal.Notify(c, os.Interrupt, syscall.SIGTERM)
 
 	alerter := alerter.NewAlerter()
 
+	// For now, we only use the global printer to print progress and information about the current scan, so unless one
+	// of the configured output should silence global output we simply use console by default.
+	if output.ShouldPrint(opts.Output, opts.Quiet) {
+		globaloutput.ChangePrinter(globaloutput.NewConsolePrinter())
+	}
+
 	providerLibrary := terraform.NewProviderLibrary()
 	remoteLibrary := common.NewRemoteLibrary()
 
@@ -278,7 +291,7 @@ func scanRun(opts *pkg.ScanOptions) error {
 
 	validOutput := false
 	for _, o := range opts.Output {
-		if err = output.GetOutput(o, opts.Quiet).Write(analysis); err != nil {
+		if err = output.GetOutput(o).Write(analysis); err != nil {
 			logrus.Errorf("Error writing to output %s: %v", o.String(), err.Error())
 			continue
 		}
@@ -297,7 +310,8 @@ func scanRun(opts *pkg.ScanOptions) error {
 	globaloutput.Printf(color.WhiteString("Provider version used to scan: %s. Use --tf-provider-version to use another version.\n"), resourceSchemaRepository.ProviderVersion.String())
 
 	if !opts.DisableTelemetry {
-		telemetry.SendTelemetry(store.Bucket(memstore.TelemetryBucket))
+		tl := telemetry.NewTelemetry(&build.Build{})
+		tl.SendTelemetry(store.Bucket(memstore.TelemetryBucket))
 	}
 
 	if !analysis.IsSync() {
