@@ -31,7 +31,7 @@ func TestConsole_Write(t *testing.T) {
 			name:       "test console output",
 			goldenfile: "output.txt",
 			args: args{analysis: func() *analyser.Analysis {
-				a := fakeAnalysis()
+				a := fakeAnalysis(analyser.AnalyzerOptions{})
 				a.AddDeleted(
 					&resource.Resource{
 						Id:   "test-id-1",
@@ -108,6 +108,12 @@ func TestConsole_Write(t *testing.T) {
 			args:       args{analysis: fakeAnalysisWithGithubEnumerationError()},
 			wantErr:    false,
 		},
+		{
+			name:       "test console output without deep mode",
+			goldenfile: "output_without_deep.txt",
+			args:       args{analysis: fakeAnalysisWithoutDeep()},
+			wantErr:    false,
+		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
