@@ -159,12 +159,17 @@ func TestTerraformStateReader_AWS_Resources(t *testing.T) {
 		{name: "Api Gateway resource", dirName: "api_gateway_resource", wantErr: false},
 		{name: "Api Gateway domain name", dirName: "api_gateway_domain_name", wantErr: false},
 		{name: "Api Gateway vpc link", dirName: "api_gateway_vpc_link", wantErr: false},
+		{name: "Api Gateway V2 Api", dirName: "apigatewayv2_api", wantErr: false},
 		{name: "Api Gateway request validator", dirName: "api_gateway_request_validator", wantErr: false},
 		{name: "Api Gateway rest api policy", dirName: "api_gateway_rest_api_policy", wantErr: false},
 		{name: "Api Gateway base path mapping", dirName: "api_gateway_base_path_mapping", wantErr: false},
 		{name: "Api Gateway method", dirName: "api_gateway_method", wantErr: false},
 		{name: "Api Gateway model", dirName: "api_gateway_model", wantErr: false},
 		{name: "Api Gateway method response", dirName: "api_gateway_method_response", wantErr: false},
+		{name: "Api Gateway gateway response", dirName: "api_gateway_gateway_response", wantErr: false},
+		{name: "Api Gateway method settings", dirName: "api_gateway_method_settings", wantErr: false},
+		{name: "Api Gateway integration", dirName: "api_gateway_integration", wantErr: false},
+		{name: "Api Gateway integration response", dirName: "api_gateway_integration_response", wantErr: false},
 		{name: "AppAutoScaling Targets", dirName: "aws_appautoscaling_target", wantErr: false},
 		{name: "network acl", dirName: "aws_network_acl", wantErr: false},
 		{name: "network acl rule", dirName: "aws_network_acl_rule", wantErr: false},
@@ -269,7 +274,7 @@ func TestTerraformStateReader_Github_Resources(t *testing.T) {
 
 			if shouldUpdate {
 				var err error
-				realProvider, err = github.NewGithubTerraformProvider("", progress, "")
+				realProvider, err = github.NewGithubTerraformProvider("", progress, os.TempDir())
 				if err != nil {
 					t.Fatal(err)
 				}
@@ -345,11 +350,16 @@ func TestTerraformStateReader_Google_Resources(t *testing.T) {
 		{name: "bigquery dataset", dirName: "google_bigquery_dataset", wantErr: false},
 		{name: "bigquery table", dirName: "google_bigquery_table", wantErr: false},
 		{name: "compute address", dirName: "google_compute_address", wantErr: false},
+		{name: "compute global address", dirName: "google_compute_global_address", wantErr: false},
 		{name: "cloudfunctions function", dirName: "google_cloudfunctions_function", wantErr: false},
 		{name: "compute subnetwork", dirName: "google_compute_subnetwork", wantErr: false},
 		{name: "compute disk", dirName: "google_compute_disk", wantErr: false},
+		{name: "compute image", dirName: "google_compute_image", wantErr: false},
 		{name: "bigtable instance", dirName: "google_bigtable_instance", wantErr: false},
 		{name: "bigtable table", dirName: "google_bigtable_table", wantErr: false},
+		{name: "sql database instance", dirName: "google_sql_database_instance", wantErr: false},
+		{name: "health check", dirName: "google_compute_health_check", wantErr: false},
+		{name: "cloudrun service", dirName: "google_cloudrun_service", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -362,7 +372,7 @@ func TestTerraformStateReader_Google_Resources(t *testing.T) {
 			var realProvider *google.GCPTerraformProvider
 			providerVersion := "3.78.0"
 			var err error
-			realProvider, err = google.NewGCPTerraformProvider(providerVersion, progress, "")
+			realProvider, err = google.NewGCPTerraformProvider(providerVersion, progress, os.TempDir())
 			if err != nil {
 				t.Fatal(err)
 			}
@@ -434,7 +444,15 @@ func TestTerraformStateReader_Azure_Resources(t *testing.T) {
 		{name: "network security group", dirName: "azurerm_network_security_group", wantErr: false},
 		{name: "load balancers", dirName: "azurerm_lb", wantErr: false},
 		{name: "private dns zone", dirName: "azurerm_private_dns_zone", wantErr: false},
+		{name: "private dns a record", dirName: "azurerm_private_dns_a_record", wantErr: false},
+		{name: "private dns aaaa record", dirName: "azurerm_private_dns_aaaa_record", wantErr: false},
+		{name: "private dns cname record", dirName: "azurerm_private_dns_cname_record", wantErr: false},
+		{name: "private dns ptr record", dirName: "azurerm_private_dns_ptr_record", wantErr: false},
+		{name: "private dns mx record", dirName: "azurerm_private_dns_mx_record", wantErr: false},
+		{name: "private dns srv record", dirName: "azurerm_private_dns_srv_record", wantErr: false},
+		{name: "private dns txt record", dirName: "azurerm_private_dns_txt_record", wantErr: false},
 		{name: "images", dirName: "azurerm_image", wantErr: false},
+		{name: "ssh public key", dirName: "azurerm_ssh_public_key", wantErr: false},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -447,7 +465,7 @@ func TestTerraformStateReader_Azure_Resources(t *testing.T) {
 			var realProvider *azurerm.AzureTerraformProvider
 			providerVersion := "2.71.0"
 			var err error
-			realProvider, err = azurerm.NewAzureTerraformProvider(providerVersion, progress, "")
+			realProvider, err = azurerm.NewAzureTerraformProvider(providerVersion, progress, os.TempDir())
 			if err != nil {
 				t.Fatal(err)
 			}
