@@ -18,24 +18,23 @@ func NewAwsBucketPolicyExpander(resourceFactory resource.ResourceFactory) AwsBuc
 	}
 }
 
-func (m AwsBucketPolicyExpander) Execute(_, resourcesFromState *[]resource.Resource) error {
-	newList := make([]resource.Resource, 0)
+func (m AwsBucketPolicyExpander) Execute(_, resourcesFromState *[]*resource.Resource) error {
+	newList := make([]*resource.Resource, 0)
 	for _, res := range *resourcesFromState {
 		// Ignore all resources other than s3_bucket
-		if res.TerraformType() != aws.AwsS3BucketResourceType {
+		if res.ResourceType() != aws.AwsS3BucketResourceType {
 			newList = append(newList, res)
 			continue
 		}
 
-		bucket, _ := res.(*resource.AbstractResource)
 		newList = append(newList, res)
 
-		if hasPolicyAttached(res.TerraformId(), resourcesFromState) {
-			bucket.Attrs.SafeDelete([]string{"policy"})
+		if hasPolicyAttached(res.ResourceId(), resourcesFromState) {
+			res.Attrs.SafeDelete([]string{"policy"})
 			continue
 		}
 
-		err := m.handlePolicy(bucket, &newList)
+		err := m.handlePolicy(res, &newList)
 		if err != nil {
 			return err
 		}
@@ -44,23 +43,23 @@ func (m AwsBucketPolicyExpander) Execute(_, resourcesFromState *[]resource.Resou
 	return nil
 }
 
-func (m *AwsBucketPolicyExpander) handlePolicy(bucket *resource.AbstractResource, results *[]resource.Resource) error {
+func (m *AwsBucketPolicyExpander) handlePolicy(bucket *resource.Resource, results *[]*resource.Resource) error {
 	policyAttr, exist := bucket.Attrs.Get("policy")
 	if !exist || policyAttr == nil || policyAttr == "" {
 		return nil
 	}
 
 	data := map[string]interface{}{
-		"id":     bucket.TerraformId(),
+		"id":     bucket.ResourceId(),
 		"bucket": (*bucket.Attrs)["bucket"],
 		"policy": (*bucket.Attrs)["policy"],
 	}
 
-	newPolicy := m.resourceFactory.CreateAbstractResource(aws.AwsS3BucketPolicyResourceType, bucket.TerraformId(), data)
+	newPolicy := m.resourceFactory.CreateAbstractResource(aws.AwsS3BucketPolicyResourceType, bucket.ResourceId(), data)
 
 	*results = append(*results, newPolicy)
 	logrus.WithFields(logrus.Fields{
-		"id": newPolicy.TerraformId(),
+		"id": newPolicy.ResourceId(),
 	}).Debug("Created new policy from bucket")
 
 	bucket.Attrs.SafeDelete([]string{"policy"})
@@ -71,10 +70,10 @@ func (m *AwsBucketPolicyExpander) handlePolicy(bucket *resource.AbstractResource
 // It is mandatory since it's possible to have a aws_bucket with an inline policy
 // AND a aws_bucket_policy resource at the same time. At the end, on the AWS console,
 // the aws_bucket_policy will be used.
-func hasPolicyAttached(bucket string, resourcesFromState *[]resource.Resource) bool {
+func hasPolicyAttached(bucket string, resourcesFromState *[]*resource.Resource) bool {
 	for _, res := range *resourcesFromState {
-		if res.TerraformType() == aws.AwsS3BucketPolicyResourceType &&
-			res.TerraformId() == bucket {
+		if res.ResourceType() == aws.AwsS3BucketPolicyResourceType &&
+			res.ResourceId() == bucket {
 			return true
 		}
 	}
