@@ -15,19 +15,18 @@ func NewAwsDefaultInternetGatewayRoute() AwsDefaultInternetGatewayRoute {
 	return AwsDefaultInternetGatewayRoute{}
 }
 
-func (m AwsDefaultInternetGatewayRoute) Execute(remoteResources, resourcesFromState *[]resource.Resource) error {
-	newRemoteResources := make([]resource.Resource, 0)
+func (m AwsDefaultInternetGatewayRoute) Execute(remoteResources, resourcesFromState *[]*resource.Resource) error {
+	newRemoteResources := make([]*resource.Resource, 0)
 
 	for _, remoteResource := range *remoteResources {
 		// Ignore all resources other than routes
-		if remoteResource.TerraformType() != aws.AwsRouteResourceType {
+		if remoteResource.ResourceType() != aws.AwsRouteResourceType {
 			newRemoteResources = append(newRemoteResources, remoteResource)
 			continue
 		}
 
-		route, _ := remoteResource.(*resource.AbstractResource)
 		// Ignore all routes except the one that came from the default internet gateway
-		if !isDefaultInternetGatewayRoute(route, remoteResources) {
+		if !isDefaultInternetGatewayRoute(remoteResource, remoteResources) {
 			newRemoteResources = append(newRemoteResources, remoteResource)
 			continue
 		}
@@ -35,7 +34,7 @@ func (m AwsDefaultInternetGatewayRoute) Execute(remoteResources, resourcesFromSt
 		// Check if route is managed by IaC
 		existInState := false
 		for _, stateResource := range *resourcesFromState {
-			if resource.IsSameResource(remoteResource, stateResource) {
+			if remoteResource.Equal(stateResource) {
 				existInState = true
 				break
 			}
@@ -49,8 +48,8 @@ func (m AwsDefaultInternetGatewayRoute) Execute(remoteResources, resourcesFromSt
 
 		// Else, resource is not added to newRemoteResources slice so it will be ignored
 		logrus.WithFields(logrus.Fields{
-			"id":   route.TerraformId(),
-			"type": route.TerraformType(),
+			"id":   remoteResource.ResourceId(),
+			"type": remoteResource.ResourceType(),
 		}).Debug("Ignoring default internet gateway route as it is not managed by IaC")
 	}
 
@@ -60,13 +59,13 @@ func (m AwsDefaultInternetGatewayRoute) Execute(remoteResources, resourcesFromSt
 }
 
 // Return true if the route's target is the default internet gateway (e.g. attached to the default vpc)
-func isDefaultInternetGatewayRoute(route *resource.AbstractResource, remoteResources *[]resource.Resource) bool {
+func isDefaultInternetGatewayRoute(route *resource.Resource, remoteResources *[]*resource.Resource) bool {
 	for _, remoteResource := range *remoteResources {
-		if remoteResource.TerraformType() == aws.AwsInternetGatewayResourceType &&
-			isDefaultInternetGateway(remoteResource.(*resource.AbstractResource), remoteResources) {
+		if remoteResource.ResourceType() == aws.AwsInternetGatewayResourceType &&
+			isDefaultInternetGateway(remoteResource, remoteResources) {
 			gtwId, gtwIdExist := route.Attrs.Get("gateway_id")
 			destCIDRBlock, destCIDRBlockExist := route.Attrs.Get("destination_cidr_block")
-			return gtwIdExist && destCIDRBlockExist && gtwId == remoteResource.TerraformId() && destCIDRBlock == "0.0.0.0/0"
+			return gtwIdExist && destCIDRBlockExist && gtwId == remoteResource.ResourceId() && destCIDRBlock == "0.0.0.0/0"
 		}
 	}
 	return false
