@@ -23,13 +23,13 @@ func (e *EC2DefaultRouteTableEnumerator) SupportedType() resource.ResourceType {
 	return aws.AwsDefaultRouteTableResourceType
 }
 
-func (e *EC2DefaultRouteTableEnumerator) Enumerate() ([]resource.Resource, error) {
+func (e *EC2DefaultRouteTableEnumerator) Enumerate() ([]*resource.Resource, error) {
 	routeTables, err := e.repository.ListAllRouteTables()
 	if err != nil {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	var results []resource.Resource
+	var results []*resource.Resource
 
 	for _, routeTable := range routeTables {
 		if isMainRouteTable(routeTable) {
