@@ -29,7 +29,7 @@ func (e *EC2EbsVolumeEnumerator) Enumerate() ([]*resource.Resource, error) {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]*resource.Resource, len(volumes))
+	results := make([]*resource.Resource, 0, len(volumes))
 
 	for _, volume := range volumes {
 		results = append(
