@@ -33,7 +33,7 @@ func (e *IamUserPolicyEnumerator) Enumerate() ([]*resource.Resource, error) {
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]*resource.Resource, len(userPolicies))
+	results := make([]*resource.Resource, 0, len(userPolicies))
 
 	for _, userPolicy := range userPolicies {
 		results = append(
