@@ -29,7 +29,7 @@ func (e *AzurermVirtualNetworkEnumerator) Enumerate() ([]*resource.Resource, err
 		return nil, remoteerror.NewResourceListingError(err, string(e.SupportedType()))
 	}
 
-	results := make([]*resource.Resource, len(resources))
+	results := make([]*resource.Resource, 0, len(resources))
 
 	for _, res := range resources {
 		results = append(
