@@ -28,7 +28,7 @@ func (g *GithubBranchProtectionEnumerator) Enumerate() ([]*resource.Resource, er
 		return nil, remoteerror.NewResourceListingError(err, string(g.SupportedType()))
 	}
 
-	results := make([]*resource.Resource, len(ids))
+	results := make([]*resource.Resource, 0, len(ids))
 
 	for _, id := range ids {
 		results = append(
