@@ -33,6 +33,10 @@ func (e *GoogleComputeAddressEnumerator) Enumerate() ([]*resource.Resource, erro
 	results := make([]*resource.Resource, 0, len(resources))
 
 	for _, res := range resources {
+		// Global addresses are handled as a dedicated resource
+		if res.GetLocation() == "global" {
+			continue
+		}
 		address := ""
 		if addr, exist := res.GetAdditionalAttributes().GetFields()["address"]; exist {
 			address = addr.GetStringValue()
