@@ -20,14 +20,19 @@ const (
 	computeNetworkAssetType       = "compute.googleapis.com/Network"
 	computeSubnetworkAssetType    = "compute.googleapis.com/Subnetwork"
 	computeDiskAssetType          = "compute.googleapis.com/Disk"
+	computeImageAssetType         = "compute.googleapis.com/Image"
 	dnsManagedZoneAssetType       = "dns.googleapis.com/ManagedZone"
 	computeInstanceGroupAssetType = "compute.googleapis.com/InstanceGroup"
 	bigqueryDatasetAssetType      = "bigquery.googleapis.com/Dataset"
 	bigqueryTableAssetType        = "bigquery.googleapis.com/Table"
 	computeAddressAssetType       = "compute.googleapis.com/Address"
+	computeGlobalAddressAssetType = "compute.googleapis.com/GlobalAddress"
 	cloudFunctionsFunction        = "cloudfunctions.googleapis.com/CloudFunction"
 	bigtableInstanceAssetType     = "bigtableadmin.googleapis.com/Instance"
 	bigtableTableAssetType        = "bigtableadmin.googleapis.com/Table"
+	sqlDatabaseInstanceAssetType  = "sqladmin.googleapis.com/Instance"
+	healthCheckAssetType          = "compute.googleapis.com/HealthCheck"
+	cloudRunServiceAssetType      = "run.googleapis.com/Service"
 )
 
 type AssetRepository interface {
@@ -37,15 +42,20 @@ type AssetRepository interface {
 	SearchAllInstances() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllNetworks() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllDisks() ([]*assetpb.ResourceSearchResult, error)
+	SearchAllImages() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllDNSManagedZones() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllInstanceGroups() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllDatasets() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllTables() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllAddresses() ([]*assetpb.ResourceSearchResult, error)
+	SearchAllGlobalAddresses() ([]*assetpb.Asset, error)
 	SearchAllFunctions() ([]*assetpb.Asset, error)
 	SearchAllSubnetworks() ([]*assetpb.ResourceSearchResult, error)
 	SearchAllBigtableInstances() ([]*assetpb.Asset, error)
 	SearchAllBigtableTables() ([]*assetpb.Asset, error)
+	SearchAllSQLDatabaseInstances() ([]*assetpb.Asset, error)
+	SearchAllHealthChecks() ([]*assetpb.ResourceSearchResult, error)
+	SearchAllCloudRunServices() ([]*assetpb.ResourceSearchResult, error)
 }
 
 type assetRepository struct {
@@ -70,6 +80,8 @@ func (s assetRepository) listAllResources(ty string) ([]*assetpb.Asset, error) {
 			cloudFunctionsFunction,
 			bigtableInstanceAssetType,
 			bigtableTableAssetType,
+			sqlDatabaseInstanceAssetType,
+			computeGlobalAddressAssetType,
 		},
 	}
 	var results []*assetpb.Asset
@@ -122,6 +134,9 @@ func (s assetRepository) searchAllResources(ty string) ([]*assetpb.ResourceSearc
 			bigqueryTableAssetType,
 			computeAddressAssetType,
 			computeDiskAssetType,
+			computeImageAssetType,
+			healthCheckAssetType,
+			cloudRunServiceAssetType,
 		},
 	}
 	var results []*assetpb.ResourceSearchResult
@@ -198,6 +213,10 @@ func (s assetRepository) SearchAllAddresses() ([]*assetpb.ResourceSearchResult,
 	return s.searchAllResources(computeAddressAssetType)
 }
 
+func (s assetRepository) SearchAllGlobalAddresses() ([]*assetpb.Asset, error) {
+	return s.listAllResources(computeGlobalAddressAssetType)
+}
+
 func (s assetRepository) SearchAllFunctions() ([]*assetpb.Asset, error) {
 	return s.listAllResources(cloudFunctionsFunction)
 }
@@ -210,6 +229,10 @@ func (s assetRepository) SearchAllDisks() ([]*assetpb.ResourceSearchResult, erro
 	return s.searchAllResources(computeDiskAssetType)
 }
 
+func (s assetRepository) SearchAllImages() ([]*assetpb.ResourceSearchResult, error) {
+	return s.searchAllResources(computeImageAssetType)
+}
+
 func (s assetRepository) SearchAllBigtableInstances() ([]*assetpb.Asset, error) {
 	return s.listAllResources(bigtableInstanceAssetType)
 }
@@ -217,3 +240,15 @@ func (s assetRepository) SearchAllBigtableInstances() ([]*assetpb.Asset, error)
 func (s assetRepository) SearchAllBigtableTables() ([]*assetpb.Asset, error) {
 	return s.listAllResources(bigtableTableAssetType)
 }
+
+func (s assetRepository) SearchAllSQLDatabaseInstances() ([]*assetpb.Asset, error) {
+	return s.listAllResources(sqlDatabaseInstanceAssetType)
+}
+
+func (s assetRepository) SearchAllHealthChecks() ([]*assetpb.ResourceSearchResult, error) {
+	return s.searchAllResources(healthCheckAssetType)
+}
+
+func (s assetRepository) SearchAllCloudRunServices() ([]*assetpb.ResourceSearchResult, error) {
+	return s.searchAllResources(cloudRunServiceAssetType)
+}
