@@ -12,7 +12,7 @@ func TestAcc_AwsInternetGateway(t *testing.T) {
 	acceptance.Run(t, acceptance.AccTestCase{
 		TerraformVersion: "0.15.5",
 		Paths:            []string{"./testdata/acc/aws_internet_gateway"},
-		Args:             []string{"scan", "--filter", "Type=='aws_internet_gateway'", "--deep"},
+		Args:             []string{"scan", "--deep"},
 		RetryDestroy: acceptance.RetryConfig{
 			Attempts: 3,
 			Delay:    5 * time.Second,
