@@ -9,12 +9,15 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsDbSubnetGroupMetaData(resourceSchemaRepository)
 	initAwsDefaultSecurityGroupMetaData(resourceSchemaRepository)
 	initAwsDefaultSubnetMetaData(resourceSchemaRepository)
+	initAwsDefaultVpcMetaData(resourceSchemaRepository)
 	initAwsDefaultRouteTableMetadata(resourceSchemaRepository)
 	initAwsDynamodbTableMetaData(resourceSchemaRepository)
 	initAwsEbsSnapshotMetaData(resourceSchemaRepository)
 	initAwsInstanceMetaData(resourceSchemaRepository)
+	initAwsInternetGatewayMetaData(resourceSchemaRepository)
 	initAwsEbsVolumeMetaData(resourceSchemaRepository)
 	initAwsEipMetaData(resourceSchemaRepository)
+	initAwsEipAssociationMetaData(resourceSchemaRepository)
 	initAwsS3BucketMetaData(resourceSchemaRepository)
 	initAwsS3BucketPolicyMetaData(resourceSchemaRepository)
 	initAwsS3BucketInventoryMetadata(resourceSchemaRepository)
@@ -27,9 +30,11 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsRoute53RecordMetaData(resourceSchemaRepository)
 	initAwsRoute53ZoneMetaData(resourceSchemaRepository)
 	initAwsRoute53HealthCheckMetaData(resourceSchemaRepository)
+	initAwsRouteTableMetaData(resourceSchemaRepository)
 	initSnsTopicSubscriptionMetaData(resourceSchemaRepository)
 	initSnsTopicPolicyMetaData(resourceSchemaRepository)
 	initSnsTopicMetaData(resourceSchemaRepository)
+	initSqsQueueMetaData(resourceSchemaRepository)
 	initAwsIAMAccessKeyMetaData(resourceSchemaRepository)
 	initAwsIAMPolicyMetaData(resourceSchemaRepository)
 	initAwsIAMPolicyAttachmentMetaData(resourceSchemaRepository)
@@ -44,8 +49,17 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAwsKmsAliasMetaData(resourceSchemaRepository)
 	initAwsLambdaFunctionMetaData(resourceSchemaRepository)
 	initAwsLambdaEventSourceMappingMetaData(resourceSchemaRepository)
+	initNatGatewayMetaData(resourceSchemaRepository)
+	initAwsNetworkACLMetaData(resourceSchemaRepository)
+	initAwsNetworkACLRuleMetaData(resourceSchemaRepository)
+	initAwsDefaultNetworkACLMetaData(resourceSchemaRepository)
 	initAwsSubnetMetaData(resourceSchemaRepository)
 	initAwsSQSQueuePolicyMetaData(resourceSchemaRepository)
 	initAwsSecurityGroupRuleMetaData(resourceSchemaRepository)
 	initAwsSecurityGroupMetaData(resourceSchemaRepository)
+	initAwsRDSClusterMetaData(resourceSchemaRepository)
+	initAwsCloudformationStackMetaData(resourceSchemaRepository)
+	initAwsVpcMetaData(resourceSchemaRepository)
+	initAwsAppAutoscalingTargetMetaData(resourceSchemaRepository)
+	initAwsAppAutoscalingPolicyMetaData(resourceSchemaRepository)
 }
