@@ -15,5 +15,13 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initAzureNetworkSecurityGroupMetadata(resourceSchemaRepository)
 	initAzureLoadBalancerMetadata(resourceSchemaRepository)
 	initAzurePrivateDNSZoneMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSARecordMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSAAAARecordMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSPTRRecordMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSSRVRecordMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSMXRecordMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSTXTRecordMetaData(resourceSchemaRepository)
 	initAzureImageMetaData(resourceSchemaRepository)
+	initAzureSSHPublicKeyMetaData(resourceSchemaRepository)
+	initAzurePrivateDNSCNameRecordMetaData(resourceSchemaRepository)
 }
