@@ -28,6 +28,8 @@ func TestGoogle_Metadata_Flags(t *testing.T) {
 		GoogleBigqueryTableResourceType:           {},
 		GoogleComputeDiskResourceType:             {},
 		GoogleBigTableInstanceResourceType:        {},
+		GoogleComputeGlobalAddressResourceType:    {},
+		GoogleCloudRunServiceResourceType:         {},
 	}
 
 	schemaRepository := testresource.InitFakeSchemaRepository(tf.GOOGLE, "3.78.0")
