@@ -13,6 +13,9 @@ func InitResourcesMetadata(resourceSchemaRepository resource.SchemaRepositoryInt
 	initGoogleBigqueryTableMetadata(resourceSchemaRepository)
 	initGoogleProjectIAMMemberMetadata(resourceSchemaRepository)
 	initGoogleComputeAddressMetadata(resourceSchemaRepository)
+	initGoogleComputeGlobalAddressMetadata(resourceSchemaRepository)
 	initGoogleComputeSubnetworkMetadata(resourceSchemaRepository)
 	initGoogleComputeDiskMetadata(resourceSchemaRepository)
+	initGoogleComputeImageMetadata(resourceSchemaRepository)
+	initGoogleComputeHealthCheckMetadata(resourceSchemaRepository)
 }
