@@ -104,6 +104,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_api_gateway_rest_api": {children: []ResourceType{
 		"aws_api_gateway_resource",
 		"aws_api_gateway_rest_api_policy",
+		"aws_api_gateway_gateway_response",
 	}},
 	"aws_api_gateway_account":    {},
 	"aws_api_gateway_api_key":    {},
@@ -114,6 +115,7 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_api_gateway_stage": {},
 	"aws_api_gateway_resource": {children: []ResourceType{
 		"aws_api_gateway_method",
+		"aws_api_gateway_integration",
 	}},
 	"aws_api_gateway_domain_name":       {},
 	"aws_api_gateway_vpc_link":          {},
@@ -124,13 +126,20 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"aws_api_gateway_method": {children: []ResourceType{
 		"aws_api_gateway_method_response",
 	}},
-	"aws_api_gateway_method_response": {},
-	"aws_appautoscaling_target":       {},
+	"aws_api_gateway_method_response":  {},
+	"aws_api_gateway_gateway_response": {},
+	"aws_api_gateway_method_settings":  {},
+	"aws_api_gateway_integration": {children: []ResourceType{
+		"aws_api_gateway_integration_response",
+	}},
+	"aws_api_gateway_integration_response": {},
+	"aws_appautoscaling_target":            {},
 	"aws_rds_cluster_instance": {children: []ResourceType{
 		"aws_db_instance",
 	}},
 	"aws_appautoscaling_policy":           {},
 	"aws_appautoscaling_scheduled_action": {},
+	"aws_apigatewayv2_api":                {},
 
 	"github_branch_protection": {},
 	"github_membership":        {},
@@ -167,6 +176,11 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"google_compute_disk":            {},
 	"google_bigtable_instance":       {},
 	"google_bigtable_table":          {},
+	"google_sql_database_instance":   {},
+	"google_compute_image":           {},
+	"google_compute_health_check":    {},
+	"google_compute_global_address":  {},
+	"google_cloud_run_service":       {},
 
 	"azurerm_storage_account":   {},
 	"azurerm_storage_container": {},
@@ -176,18 +190,26 @@ var supportedTypes = map[string]ResourceTypeMeta{
 	"azurerm_route_table": {children: []ResourceType{
 		"azurerm_route",
 	}},
-	"azurerm_route":                  {},
-	"azurerm_resource_group":         {},
-	"azurerm_subnet":                 {},
-	"azurerm_container_registry":     {},
-	"azurerm_firewall":               {},
-	"azurerm_postgresql_server":      {},
-	"azurerm_postgresql_database":    {},
-	"azurerm_public_ip":              {},
-	"azurerm_network_security_group": {},
-	"azurerm_lb":                     {},
-	"azurerm_private_dns_zone":       {},
-	"azurerm_image":                  {},
+	"azurerm_route":                    {},
+	"azurerm_resource_group":           {},
+	"azurerm_subnet":                   {},
+	"azurerm_container_registry":       {},
+	"azurerm_firewall":                 {},
+	"azurerm_postgresql_server":        {},
+	"azurerm_postgresql_database":      {},
+	"azurerm_public_ip":                {},
+	"azurerm_network_security_group":   {},
+	"azurerm_lb":                       {},
+	"azurerm_private_dns_zone":         {},
+	"azurerm_private_dns_a_record":     {},
+	"azurerm_private_dns_aaaa_record":  {},
+	"azurerm_private_dns_cname_record": {},
+	"azurerm_private_dns_ptr_record":   {},
+	"azurerm_private_dns_srv_record":   {},
+	"azurerm_private_dns_mx_record":    {},
+	"azurerm_private_dns_txt_record":   {},
+	"azurerm_image":                    {},
+	"azurerm_ssh_public_key":           {},
 }
 
 func IsResourceTypeSupported(ty string) bool {
